/*
 * access.h:  Access control definitions
 *
 * Author:
 *	Dick Porter (dick@ximian.com)
 *
 * (C) 2002 Ximian, Inc.
 */

#ifndef _WAPI_ACCESS_H_
#define _WAPI_ACCESS_H_

#include <glib.h>

#include <mono/io-layer/wapi.h>

#define SYNCHRONIZE			0x00100000
#define STANDARD_RIGHTS_REQUIRED	0x000f0000

#endif /* _WAPI_ACCESS_H_ */
